@@ -94,10 +94,8 @@ GLWidget::GLWidget(QMainWindow *parent) : QGLWidget(parent) {
 
 	timer = new QTimer(this);
 	connect(timer, SIGNAL(timeout()), this, SLOT(paivita()));
-	timer->start(20);
 	QTimer *avoiding = new QTimer(this);
 	aikaKello = new QTimer(this);
-	aikaKello->start(1000);
 	connect(avoiding, SIGNAL(timeout()), this, SLOT(avoidScreensaver()));
 	connect(aikaKello, SIGNAL(timeout()), this, SLOT(lisaaAikaa()));
 	
@@ -109,11 +107,8 @@ GLWidget::GLWidget(QMainWindow *parent) : QGLWidget(parent) {
 	layout->addWidget(quitButton);
 	this->setLayout(layout);
 	quitButton->hide();
-	showQuitButton = false;
-	
-	connect(quitButton, SIGNAL(clicked()), this, SLOT(hideGame()));	
-	
-	
+	showQuitButton = false;	
+	connect(quitButton, SIGNAL(clicked()), this, SLOT(hideGame()));		
 }
 
 void GLWidget::newGame() {
@@ -568,10 +563,10 @@ void GLWidget::displayStateChanged(const QDBusMessage &message) {
 void GLWidget::setDisplayState(const QString &state) {
 	if(!state.isEmpty()) {
 		if(state == MCE_DISPLAY_ON_STRING) {
-			resumeGame();
+			if(keskeytetty) resumeGame();
 		}
 		else if(state == MCE_DISPLAY_OFF_STRING) {
-			pauseGame();
+			if(!isHidden()) pauseGame();
 		}
 	}
 }
